@@ -7,7 +7,7 @@ package MarpaX::ESLIF::Grammar::Symbol::Properties;
 
 our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
-our $VERSION = '6.0.1'; # TRIAL VERSION
+our $VERSION = '6.0.2'; # TRIAL VERSION
 
 
 #
@@ -44,6 +44,7 @@ sub new {
         'eventBitSet'                => $args{eventBitSet},
         'symbolAction'               => $args{symbolAction},
         'ifAction'                   => $args{ifAction},
+        'generatorAction'            => $args{generatorAction},
         'verbose'                    => $args{verbose}
     };
 
@@ -295,6 +296,13 @@ sub getIfAction {
 }
 
 
+sub getGeneratorAction {
+    my ($self) = @_;
+
+    return $self->{generatorAction}
+}
+
+
 sub isVerbose {
     my ($self) = @_;
 
@@ -318,7 +326,7 @@ MarpaX::ESLIF::Grammar::Symbol::Properties - ESLIF Grammar Symbol Properties
 
 =head1 VERSION
 
-version 6.0.1
+version 6.0.2
 
 =head1 SYNOPSIS
 
@@ -360,8 +368,8 @@ version 6.0.1
   whitespaces ::= WHITESPACES
   comment ::= /(?:(?:(?:\/\/)(?:[^\n]*)(?:\n|\z))|(?:(?:\/\*)(?:(?:[^\*]+|\*(?!\/))*)(?:\*\/)))/u
 
-  :lexeme ::= NUMBER pause => before event => ^NUMBER
-  :lexeme ::= NUMBER pause => after  event => NUMBER$
+  :symbol ::= NUMBER pause => before event => ^NUMBER
+  :symbol ::= NUMBER pause => after  event => NUMBER$
 
   :desc      ~ 'Calculator Tokens'
   NUMBER     ~ /[\d]+/   name => 'NUMBER Lexeme'
@@ -541,6 +549,10 @@ Returns the symbol specific action, null if there is none
 
 Returns the symbol if action, null if there is none
 
+=head2 $self->getGeneratorAction
+
+Returns the symbol generator action, null if there is none
+
 =head2 $self->isVerbose
 
 Returns if the symbol is verbose
