@@ -16,7 +16,7 @@ sub _EQ       { return }
 
 our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
-our $VERSION = '6.0.1'; # TRIAL VERSION
+our $VERSION = '6.0.2'; # TRIAL VERSION
 
 
 sub _allocate_newFrom {
@@ -38,6 +38,27 @@ sub newFrom {
 }
 
 
+sub lexemeAlternative { goto &alternative }
+
+
+sub lexemeComplete { goto &alternativeComplete }
+
+
+sub lexemeRead { goto &alternativeRead }
+
+
+sub lexemeTry { goto &nameTry }
+
+
+sub lexemeExpected { goto &nameExpected }
+
+
+sub lexemeLastPause { goto &nameLastPause }
+
+
+sub lexemeLastTry { goto &nameLastTry }
+
+
 sub CLONE_SKIP {
     return 1
 }
@@ -56,7 +77,7 @@ MarpaX::ESLIF::Recognizer - MarpaX::ESLIF's recognizer
 
 =head1 VERSION
 
-version 6.0.1
+version 6.0.2
 
 =head1 SYNOPSIS
 
@@ -287,15 +308,21 @@ This method is similar to the isEof()'s recognizer interface. Except that this i
 
 Returns a boolean indicating of end-of-user-data is reached.
 
+=head2 $eslifRecognizer->isStartComplete()
+
+Returns a boolean indicating if start symbol completion is reached. Note that this does not mean that the grammar is exhausted.
+
 =head2 $eslifRecognizer->read()
 
 Forces the recognizer to read more data. Usually, the recognizer interface is called automatically whenever needed.
 
 Returns a boolean value indicating success or not.
 
-=head2 $eslifRecognizer->input()
+=head2 $eslifRecognizer->input([offset[, length]])
 
-Get a copy of the current internal recognizer buffer, starting at the exact byte where resume() would start. An undefined output does not mean there is an error, but that internal buffers are completely consumed. ESLIF will automatically require more data unless the EOF flag is set. Internal buffer is always UTF-8 encoded to every chunk of data that was declared to be a character stream.
+Get a copy of the current internal recognizer buffer, where C<offset> and C<length> are in I<byte> unit and with the same semantics as builtin C<substr> function for the C<offset> parameter, same semantics for the C<length> parameter as well when it is not C<0> (the zero value is ignored). An undefined output does not necessarily mean there is an error, but that the internal buffer is completely consumed. It is recommended to set C<length> parameter to a reasonable value, to prevent an internal copy of a potentially big number of bytes.
+
+Default values for C<offset> and <length> are C<0>.
 
 Returns the associated input input, or C<undef>.
 
@@ -419,6 +446,36 @@ Hook the recognizer to switch the use of C<:discard> if it exists. This is a I<p
 
 Tries to match the external symbol C<$symbol>, that is an instance of L<MarpaX::ESLIF::Symbol>. Return the match or C<undef>.
 
+=head1 DEPRECATED METHODS
+
+=head2 $eslifRecognizer->lexemeAlternative($name, $anything, $grammarLength)
+
+Alias to C<alternative>.
+
+=head2 $eslifRecognizer->lexemeComplete($length)
+
+Alias to C<alternativeComplete>.
+
+=head2 $eslifRecognizer->lexemeRead($name, $anything, $length, $grammarLength)
+
+Alias to C<alternativeRead>.
+
+=head2 $eslifRecognizer->lexemeTry($name)
+
+Alias to C<nameTry>.
+
+=head2 $eslifRecognizer->lexemeExpected()
+
+Alias to C<nameExpected>.
+
+=head2 $eslifRecognizer->lexemeLastPause($name)
+
+Alias to C<nameLastPause>.
+
+=head2 $eslifRecognizer->lexemeLastTry($name)
+
+Alias to C<nameLastTry>.
+
 =head1 SEE ALSO
 
 L<MarpaX::ESLIF::Recognizer::Interface>, L<MarpaX::ESLIF::Event::Type>, L<MarpaX::ESLIF::Logger::Level>, L<MarpaX::ESLIF::Symbol>
