@@ -22,6 +22,7 @@
 #define G1_RULE_STATEMENT_18                     "G1_rule_statement_18"
 #define G1_RULE_STATEMENT_19                     "G1_rule_statement_19"
 #define G1_RULE_STATEMENT_20                     "G1_rule_statement_20"
+#define G1_RULE_STATEMENT_21                     "G1_rule_statement_21"
 #define G1_RULE_START_RULE                       "G1_rule_start_rule"
 #define G1_RULE_START_SYMBOL_1                   "G1_rule_start_symbol_1"
 #define G1_RULE_START_SYMBOL_2                   "G1_rule_start_symbol_2"
@@ -35,6 +36,7 @@
 #define G1_RULE_DEFAULT_RULE                     "G1_rule_default_rule"
 #define G1_RULE_LEXEME_RULE                      "G1_rule_lexeme_rule"
 #define G1_RULE_TERMINAL_RULE                    "G1_rule_terminal_rule"
+#define G1_RULE_SYMBOL_RULE                      "G1_rule_symbol_rule"
 #define G1_RULE_COMPLETION_EVENT_DECLARATION_1   "G1_rule_completion_event_declaration_1"
 #define G1_RULE_COMPLETION_EVENT_DECLARATION_2   "G1_rule_completion_event_declaration_2"
 #define G1_RULE_NULLED_EVENT_DECLARATION_1       "G1_rule_nulled_event_declaration_1"
@@ -134,6 +136,7 @@
 #define G1_RULE_RHS_ALTERNATIVE_10               "G1_rule_rhs_alternative_10"
 #define G1_RULE_RHS_PRIMARY_NO_PARAMETER_1       "G1_rule_rhs_primary_no_parameter_1"
 #define G1_RULE_RHS_PRIMARY_NO_PARAMETER_2       "G1_rule_rhs_primary_no_parameter_2"
+#define G1_RULE_RHS_PRIMARY_NO_PARAMETER_3       "G1_rule_rhs_primary_no_parameter_3"
 #define G1_RULE_RHS_PRIMARY_1                    "G1_rule_rhs_primary_1"
 #define G1_RULE_RHS_PRIMARY_2                    "G1_rule_rhs_primary_2"
 #define G1_RULE_RHS_PRIMARY_3                    "G1_rule_rhs_primary_3"
@@ -245,6 +248,7 @@
 #define G1_ACTION_STATEMENT_18                     "::undef"
 #define G1_ACTION_STATEMENT_19                     "::undef"
 #define G1_ACTION_STATEMENT_20                     "::undef"
+#define G1_ACTION_STATEMENT_21                     "::undef"
 #define G1_ACTION_START_RULE                       "G1_action_start_rule"                       /* done */
 #define G1_ACTION_START_SYMBOL_1                   "G1_action_start_symbol_1"                   /* done */
 #define G1_ACTION_START_SYMBOL_2                   "G1_action_start_symbol_2"                   /* done */
@@ -258,6 +262,7 @@
 #define G1_ACTION_DEFAULT_RULE                     "G1_action_default_rule"                     /* done */
 #define G1_ACTION_LEXEME_RULE                      "G1_action_lexeme_rule"                      /* done */
 #define G1_ACTION_TERMINAL_RULE                    "G1_action_terminal_rule"                    /* done */
+#define G1_ACTION_SYMBOL_RULE                      "G1_action_symbol_rule"                      /* done */
 #define G1_ACTION_COMPLETION_EVENT_DECLARATION_1   "G1_action_completion_event_declaration_1"   /* done */
 #define G1_ACTION_COMPLETION_EVENT_DECLARATION_2   "G1_action_completion_event_declaration_2"   /* done */
 #define G1_ACTION_NULLED_EVENT_DECLARATION_1       "G1_action_nulled_event_declaration_1"       /* done */
@@ -356,6 +361,7 @@
 #define G1_ACTION_RHS_ALTERNATIVE_10               "G1_action_rhs_alternative_10"               /* done */
 #define G1_ACTION_RHS_PRIMARY_NO_PARAMETER_1       "G1_action_rhs_primary_no_parameter_1"       /* done */
 #define G1_ACTION_RHS_PRIMARY_NO_PARAMETER_2       "G1_action_rhs_primary_no_parameter_2"       /* done */
+#define G1_ACTION_RHS_PRIMARY_NO_PARAMETER_3       "G1_action_rhs_primary_no_parameter_3"       /* done */
 #define G1_ACTION_RHS_PRIMARY_1                    "::shift"                                    /* done */
 #define G1_ACTION_RHS_PRIMARY_2                    "G1_action_rhs_primary_2"                    /* done */
 #define G1_ACTION_RHS_PRIMARY_3                    "G1_action_rhs_primary_3"                    /* done */
