@@ -26,27 +26,29 @@
 #define INTERNAL_CHARACTERCLASSMODIFIERS_PATTERN "[eijmnsxDJUuaNubcA]+$"
 #define INTERNAL_REGEXMODIFIERS_PATTERN "[eijmnsxDJUuaNubcA]*$"
 
-typedef struct  marpaESLIF_regex            marpaESLIF_regex_t;
-typedef         marpaESLIFString_t          marpaESLIF_string_t;
-typedef enum    marpaESLIF_symbol_type      marpaESLIF_symbol_type_t;
-typedef enum    marpaESLIF_terminal_type    marpaESLIF_terminal_type_t;
-typedef struct  marpaESLIF_terminal         marpaESLIF_terminal_t;
-typedef struct  marpaESLIF_meta             marpaESLIF_meta_t;
-typedef         marpaESLIFSymbol_t          marpaESLIF_symbol_t;
-typedef struct  marpaESLIF_rule             marpaESLIF_rule_t;
-typedef struct  marpaESLIF_grammar          marpaESLIF_grammar_t;
-typedef enum    marpaESLIF_matcher_value    marpaESLIF_matcher_value_t;
-typedef enum    marpaESLIF_event_type       marpaESLIF_event_type_t;
-typedef struct  marpaESLIF_readerContext    marpaESLIF_readerContext_t;
-typedef struct  marpaESLIF_cloneContext     marpaESLIF_cloneContext_t;
-typedef struct  marpaESLIF_symbol_data      marpaESLIF_symbol_data_t;
-typedef struct  marpaESLIF_alternative      marpaESLIF_alternative_t;
-typedef         marpaESLIFAction_t          marpaESLIF_action_t;
-typedef         marpaESLIFActionType_t      marpaESLIF_action_type_t;
-typedef struct  marpaESLIF_stream           marpaESLIF_stream_t;
-typedef struct  marpaESLIF_stringGenerator  marpaESLIF_stringGenerator_t;
-typedef struct  marpaESLIF_lua_functioncall marpaESLIF_lua_functioncall_t;
-typedef struct  marpaESLIF_lua_functiondecl marpaESLIF_lua_functiondecl_t;
+typedef struct  marpaESLIF_regex                 marpaESLIF_regex_t;
+typedef         marpaESLIFString_t               marpaESLIF_string_t;
+typedef enum    marpaESLIF_symbol_type           marpaESLIF_symbol_type_t;
+typedef enum    marpaESLIF_terminal_type         marpaESLIF_terminal_type_t;
+typedef struct  marpaESLIF_terminal              marpaESLIF_terminal_t;
+typedef struct  marpaESLIF_meta                  marpaESLIF_meta_t;
+typedef         marpaESLIFSymbol_t               marpaESLIF_symbol_t;
+typedef struct  marpaESLIF_rule                  marpaESLIF_rule_t;
+typedef struct  marpaESLIF_grammar               marpaESLIF_grammar_t;
+typedef enum    marpaESLIF_matcher_value         marpaESLIF_matcher_value_t;
+typedef enum    marpaESLIF_event_type            marpaESLIF_event_type_t;
+typedef struct  marpaESLIF_readerContext         marpaESLIF_readerContext_t;
+typedef struct  marpaESLIF_cloneContext          marpaESLIF_cloneContext_t;
+typedef struct  marpaESLIF_symbol_data           marpaESLIF_symbol_data_t;
+typedef struct  marpaESLIF_alternative           marpaESLIF_alternative_t;
+typedef         marpaESLIFAction_t               marpaESLIF_action_t;
+typedef         marpaESLIFActionType_t           marpaESLIF_action_type_t;
+typedef struct  marpaESLIF_stream                marpaESLIF_stream_t;
+typedef struct  marpaESLIF_stringGenerator       marpaESLIF_stringGenerator_t;
+typedef struct  marpaESLIF_lua_functioncall      marpaESLIF_lua_functioncall_t;
+typedef struct  marpaESLIF_lua_functiondecl      marpaESLIF_lua_functiondecl_t;
+typedef enum    marpaESLIF_json_type             marpaESLIF_json_type_t;
+typedef struct  marpaESLIF_pcre2_callout_context marpaESLIF_pcre2_callout_context_t;
 
 #include "marpaESLIF/internal/lua.h" /* For lua_State* */
 
@@ -134,6 +136,11 @@ struct marpaESLIF_regex_option_map {
   { 'A', NULL,                                       0,                                        "PCRE2_ANCHORED",  PCRE2_ANCHORED }
 };
 
+struct marpaESLIF_pcre2_callout_context {
+  marpaESLIFRecognizer_t *marpaESLIFRecognizerp;
+  marpaESLIF_terminal_t  *terminalp;
+};
+
 struct marpaESLIF_regex {
   pcre2_code            *patternp;     /* Compiled pattern */
   pcre2_match_data      *match_datap;  /* Match data */
@@ -143,8 +150,10 @@ struct marpaESLIF_regex {
 #endif
   short                  isAnchoredb;  /* Remember if pattern was allocated with PCRE2_ANCHORED (set automatically or not) */
   short                  utfb;         /* Is UTF mode enabled in that pattern ? */
-  pcre2_compile_context *ccontextp;    /* Output of pcre2_compile_context */
+  pcre2_compile_context *compile_contextp;    /* Output of pcre2_compile_context */
   short                  calloutb;     /* Do this regex have any callout ? */
+  pcre2_match_context   *match_contextp;    /* Match context */
+  marpaESLIF_pcre2_callout_context_t callout_context; /* Callout match */
 };
 
 struct marpaESLIF_terminal {
@@ -182,6 +191,12 @@ enum marpaESLIF_event_type {
 
 /* A symbol */
 struct marpaESLIFSymbol {
+  /* For faster lookup we put these elements at the beginning of the structure - these are all shallow pointers */
+  marpaESLIFAction_t                  *effectiveNullableActionp;
+  marpaESLIF_internal_rule_action_t    effectiveNullableActione;
+  marpaESLIFAction_t                  *effectiveSymbolActionp;
+  marpaESLIF_internal_symbol_action_t  effectiveSymbolActione;
+
   marpaESLIF_symbol_type_t       type;  /* Symbol type */
   union {
     marpaESLIF_terminal_t       *terminalp; /* Symbol is a terminal */
@@ -248,6 +263,10 @@ struct marpaESLIFSymbol {
 
 /* A rule */
 struct marpaESLIF_rule {
+  /* For faster lookup we put these elements at the beginning of the structure - these are all shallow pointers */
+  marpaESLIFAction_t                *effectiveRuleActionp;
+  marpaESLIF_internal_rule_action_t  effectiveRuleActione;
+
   int                             idi;                          /* Rule Id */
   marpaESLIF_string_t            *descp;                        /* Rule alternative name */
   short                           descautob;                    /* True if alternative name was autogenerated */
@@ -322,9 +341,12 @@ struct marpaESLIF_grammar {
   short                  fastDiscardb;                       /* True when :discard can be done in the context of the current recognizer */
 };
 
-/* ----------------------------------- */
-/* Definition of the opaque structures */
-/* ----------------------------------- */
+enum marpaESLIF_json_type {
+  MARPAESLIF_JSON_TYPE_STRICT = 0,
+  MARPAESLIF_JSON_TYPE_EXTENDED,
+  _MARPAESLIF_JSON_TYPE_LAST
+};
+
 #define MARPAESLIFGRAMMARLUA_FOR_PARLIST 0
 #define MARPAESLIFGRAMMARLUA_FOR_EXPLIST 1
 struct marpaESLIF {
@@ -368,6 +390,9 @@ struct marpaESLIF {
   float                   negativenanf;                /* -NaN */
   short                   nanconfidenceb;              /* 1 when ESLIF think that NaN representation is correct */
 #endif
+  /* For JSON grammars : the symbols that depend on strictness */
+  marpaESLIF_symbol_t    *jsonStringpp[_MARPAESLIF_JSON_TYPE_LAST];
+  marpaESLIF_symbol_t    *jsonConstantOrNumberpp[_MARPAESLIF_JSON_TYPE_LAST];
 };
 
 struct marpaESLIFGrammar {
@@ -392,6 +417,9 @@ struct marpaESLIFGrammar {
   genericHash_t              _lexemeGrammarHash; /* Cache of string <=> lexeme grammars */
   genericHash_t             *lexemeGrammarHashp;
   short                      hasLookaheadMetab;  /* Any lookahead meta in the grammar ? */
+  /* For JSON grammars : the symbols that depend on strictness */
+  marpaESLIF_symbol_t       *jsonStringp; /* Shallow pointer */
+  marpaESLIF_symbol_t       *jsonConstantOrNumberp; /* Shallow pointer */
 };
 
 struct marpaESLIF_meta {
@@ -577,6 +605,7 @@ struct marpaESLIFRecognizer {
   marpaESLIFValueResult_t     *marpaESLIFCalloutBlockp;
 
   /* We always maintain a shallow pointer to the top-level recognizer, to ease access to lua state */
+  /* This variable should be used ONLY IN src/lua.c (modulo initialization and propagation that are in src/marpaESLIF.c) */
   marpaESLIFRecognizer_t      *marpaESLIFRecognizerTopp;
 
   /* At every recognizer pass, we use this array whose size is equal to the total number of marpa grammar terminals */
